@@ -1,3 +1,6 @@
+// SPDX-FileCopyrightText: Copyright The Lima Authors
+// SPDX-License-Identifier: Apache-2.0
+
 package yqutil
 
 import (
@@ -93,9 +96,6 @@ func EvaluateExpression(expression string, content []byte) ([]byte, error) {
 }
 
 func Join(yqExprs []string) string {
-	if len(yqExprs) == 0 {
-		return ""
-	}
 	return strings.Join(yqExprs, " | ")
 }
 
